Jforrester has uploaded a new change for review. ( 
https://gerrit.wikimedia.org/r/338907 )

Change subject: maintenance: Replace implicit Bugzilla bug numbers with Phab 
ones
......................................................................

maintenance: Replace implicit Bugzilla bug numbers with Phab ones

It's unreasonable to expect newbies to know that "bug 12345" means "Task T14345"
except where it doesn't, so let's just standardise on the real numbers.

This includes renaming fixBug20757.php to fixT22757.php for similar consistency.

Change-Id: If81a590d658fbd82c20c54ac47dfdc8856745ca3
---
M maintenance/archives/patch-archive-ar_id.sql
M maintenance/archives/patch-categorylinks-better-collation.sql
M maintenance/archives/patch-externallinks-el_id.sql
M maintenance/archives/patch-up_property.sql
M maintenance/benchmarks/bench_utf8_title_check.php
M maintenance/cleanupImages.php
M maintenance/cleanupTitles.php
M maintenance/fixDoubleRedirects.php
M maintenance/generateSitemap.php
M maintenance/migrateUserGroup.php
M maintenance/mssql/tables.sql
M maintenance/populateRevisionLength.php
M maintenance/populateRevisionSha1.php
M maintenance/rebuildFileCache.php
M maintenance/sql.php
M maintenance/sqlite/archives/initial-indexes.sql
R maintenance/storage/fixT22757.php
M maintenance/storage/trackBlobs.php
M maintenance/tables.sql
M maintenance/update.php
20 files changed, 35 insertions(+), 35 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/07/338907/1

diff --git a/maintenance/archives/patch-archive-ar_id.sql 
b/maintenance/archives/patch-archive-ar_id.sql
index ddd1d7b..08287cd 100644
--- a/maintenance/archives/patch-archive-ar_id.sql
+++ b/maintenance/archives/patch-archive-ar_id.sql
@@ -1,7 +1,7 @@
 --
 -- patch-archive-ar_id.sql
 --
--- Bug 39675. Add archive.ar_id.
+-- T41675. Add archive.ar_id.
 
 ALTER TABLE /*$wgDBprefix*/archive
     ADD COLUMN ar_id int unsigned NOT NULL AUTO_INCREMENT FIRST,
diff --git a/maintenance/archives/patch-categorylinks-better-collation.sql 
b/maintenance/archives/patch-categorylinks-better-collation.sql
index f5ff1f1..f8b6340 100644
--- a/maintenance/archives/patch-categorylinks-better-collation.sql
+++ b/maintenance/archives/patch-categorylinks-better-collation.sql
@@ -1,11 +1,11 @@
 --
 -- patch-categorylinks-better-collation.sql
 --
--- Bugs 164, 1211, 23682.  This is the second version of this patch; the
+-- T2164, T3211, T25682.  This is the second version of this patch; the
 -- changes are also incorporated into 
patch-categorylinks-better-collation2.sql,
 -- for the benefit of trunk users who applied the original.
 --
--- Due to bug 25254, the length limit of 255 bytes for cl_sortkey_prefix
+-- Due to T27254, the length limit of 255 bytes for cl_sortkey_prefix
 -- is also enforced in php. If you change the length of that field, make
 -- sure to also change the check in LinksUpdate.php.
 ALTER TABLE /*$wgDBprefix*/categorylinks
diff --git a/maintenance/archives/patch-externallinks-el_id.sql 
b/maintenance/archives/patch-externallinks-el_id.sql
index d4b51b5..ded8454 100644
--- a/maintenance/archives/patch-externallinks-el_id.sql
+++ b/maintenance/archives/patch-externallinks-el_id.sql
@@ -1,7 +1,7 @@
 --
 -- patch-extenallinks-el_id.sql
 --
--- Bug 15441. Add externallinks.el_id.
+-- T17441. Add externallinks.el_id.
 
 ALTER TABLE /*$wgDBprefix*/externallinks
     ADD COLUMN el_id int unsigned NOT NULL AUTO_INCREMENT FIRST,
diff --git a/maintenance/archives/patch-up_property.sql 
b/maintenance/archives/patch-up_property.sql
index 742841e..c516aaf 100644
--- a/maintenance/archives/patch-up_property.sql
+++ b/maintenance/archives/patch-up_property.sql
@@ -1,4 +1,4 @@
--- Increase the length of up_property from 32 -> 255 bytes. Bug 19408
+-- Increase the length of up_property from 32 -> 255 bytes. T21408
 
 ALTER TABLE /*_*/user_properties
        MODIFY up_property varbinary(255);
diff --git a/maintenance/benchmarks/bench_utf8_title_check.php 
b/maintenance/benchmarks/bench_utf8_title_check.php
index c92a720..b2f7e96 100644
--- a/maintenance/benchmarks/bench_utf8_title_check.php
+++ b/maintenance/benchmarks/bench_utf8_title_check.php
@@ -41,7 +41,7 @@
                        "United States of America", // 7bit ASCII
                        "S%C3%A9rie%20t%C3%A9l%C3%A9vis%C3%A9e",
                        
"Acteur%7CAlbert%20Robbins%7CAnglais%7CAnn%20Donahue%7CAnthony%20E.%20Zuiker%7CCarol%20Mendelsohn",
-                       // This comes from bug 36839
+                       // This comes from T38839
                        
"Acteur%7CAlbert%20Robbins%7CAnglais%7CAnn%20Donahue%7CAnthony%20E.%20Zuiker%7CCarol%20Mendelsohn%7C"
                        . 
"Catherine%20Willows%7CDavid%20Hodges%7CDavid%20Phillips%7CGil%20Grissom%7CGreg%20Sanders%7CHodges%7C"
                        . 
"Internet%20Movie%20Database%7CJim%20Brass%7CLady%20Heather%7C"
diff --git a/maintenance/cleanupImages.php b/maintenance/cleanupImages.php
index c8f393d..e0da027 100644
--- a/maintenance/cleanupImages.php
+++ b/maintenance/cleanupImages.php
@@ -146,7 +146,7 @@
                 * if the target title exists in the image table, or if both the
                 * original and target titles exist in the page table, append
                 * increasing version numbers until the target title exists in
-                * neither.  (See also bug 16916.)
+                * neither.  (See also T18916.)
                 */
                $version = 0;
                $final = $new;
diff --git a/maintenance/cleanupTitles.php b/maintenance/cleanupTitles.php
index 650fae0..ccc6406 100644
--- a/maintenance/cleanupTitles.php
+++ b/maintenance/cleanupTitles.php
@@ -138,14 +138,14 @@
                                $prior = $title->getDBkey();
                        }
 
-                       # Old cleanupTitles could move articles there. See bug 
23147.
+                       # Old cleanupTitles could move articles there. See 
T25147.
                        $ns = $row->page_namespace;
                        if ( $ns < 0 ) {
                                $ns = 0;
                        }
 
                        # Namespace which no longer exists. Put the page in the 
main namespace
-                       # since we don't have any idea of the old namespace 
name. See bug 68501.
+                       # since we don't have any idea of the old namespace 
name. See T70501.
                        if ( !MWNamespace::exists( $ns ) ) {
                                $ns = 0;
                        }
diff --git a/maintenance/fixDoubleRedirects.php 
b/maintenance/fixDoubleRedirects.php
index 1d6f31d..79f75ef 100644
--- a/maintenance/fixDoubleRedirects.php
+++ b/maintenance/fixDoubleRedirects.php
@@ -72,7 +72,7 @@
                        'rd_from = pa.page_id',
                        'rd_namespace = pb.page_namespace',
                        'rd_title = pb.page_title',
-                       'rd_interwiki IS NULL OR rd_interwiki = ' . 
$dbr->addQuotes( '' ), // bug 40352
+                       'rd_interwiki IS NULL OR rd_interwiki = ' . 
$dbr->addQuotes( '' ), // T42352
                        'pb.page_is_redirect' => 1,
                ];
 
diff --git a/maintenance/generateSitemap.php b/maintenance/generateSitemap.php
index 87af5b8..fb00bed 100644
--- a/maintenance/generateSitemap.php
+++ b/maintenance/generateSitemap.php
@@ -523,7 +523,7 @@
        function fileEntry( $url, $date, $priority ) {
                return
                        "\t<url>\n" .
-                       // bug 34666: $url may contain bad characters such as 
ampersands.
+                       // T36666: $url may contain bad characters such as 
ampersands.
                        "\t\t<loc>" . htmlspecialchars( $url ) . "</loc>\n" .
                        "\t\t<lastmod>$date</lastmod>\n" .
                        "\t\t<priority>$priority</priority>\n" .
@@ -545,7 +545,7 @@
         * @param int $namespace
         */
        function generateLimit( $namespace ) {
-               // bug 17961: make a title with the longest possible URL in 
this namespace
+               // T19961: make a title with the longest possible URL in this 
namespace
                $title = Title::makeTitle( $namespace, str_repeat( 
"\xf0\xa8\xae\x81", 63 ) . "\xe5\x96\x83" );
 
                $this->limit = [
diff --git a/maintenance/migrateUserGroup.php b/maintenance/migrateUserGroup.php
index 396be1d..597a876 100644
--- a/maintenance/migrateUserGroup.php
+++ b/maintenance/migrateUserGroup.php
@@ -79,7 +79,7 @@
                        $affected += $dbw->affectedRows();
                        $this->commitTransaction( $dbw, __METHOD__ );
 
-                       // Clear cache for the affected users (bug 40340)
+                       // Clear cache for the affected users (T42340)
                        if ( $affected > 0 ) {
                                // XXX: This also invalidates cache of 
unaffected users that
                                // were in the new group and not in the group.
diff --git a/maintenance/mssql/tables.sql b/maintenance/mssql/tables.sql
index 1c633be..78f0671 100644
--- a/maintenance/mssql/tables.sql
+++ b/maintenance/mssql/tables.sql
@@ -301,7 +301,7 @@
   -- conversion algorithm is run.  We store this so that we can update
   -- collations without reparsing all pages.
   -- Note: If you change the length of this field, you also need to change
-  -- code in LinksUpdate.php. See bug 25254.
+  -- code in LinksUpdate.php. See T27254.
   cl_sortkey_prefix varbinary(255) NOT NULL default 0x,
 
   -- This isn't really used at present. Provided for an optional
@@ -528,7 +528,7 @@
   -- Size chosen to allow IPv6
   -- FIXME: these fields were originally blank for single-IP blocks,
   -- but now they are populated. No migration was ever done. They
-  -- should be fixed to be blank again for such blocks (bug 49504).
+  -- should be fixed to be blank again for such blocks (T51504).
   ipb_range_start varchar(255) NOT NULL,
   ipb_range_end varchar(255) NOT NULL,
 
diff --git a/maintenance/populateRevisionLength.php 
b/maintenance/populateRevisionLength.php
index 5e44faf..a9457c2 100644
--- a/maintenance/populateRevisionLength.php
+++ b/maintenance/populateRevisionLength.php
@@ -136,7 +136,7 @@
 
                $content = $rev->getContent();
                if ( !$content ) {
-                       # This should not happen, but sometimes does (bug 20757)
+                       # This should not happen, but sometimes does (T22757)
                        $id = $row->$idCol;
                        $this->output( "Content of $table $id unavailable!\n" );
 
diff --git a/maintenance/populateRevisionSha1.php 
b/maintenance/populateRevisionSha1.php
index 095c266..fb97e91 100644
--- a/maintenance/populateRevisionSha1.php
+++ b/maintenance/populateRevisionSha1.php
@@ -156,10 +156,10 @@
                } catch ( Exception $e ) {
                        $this->output( "Data of revision with 
{$idCol}={$row->$idCol} unavailable!\n" );
 
-                       return false; // bug 22624?
+                       return false; // T24624?
                }
                if ( !is_string( $text ) ) {
-                       # This should not happen, but sometimes does (bug 20757)
+                       # This should not happen, but sometimes does (T22757)
                        $this->output( "Data of revision with 
{$idCol}={$row->$idCol} unavailable!\n" );
 
                        return false;
@@ -185,11 +185,11 @@
                } catch ( Exception $e ) {
                        $this->output( "Text of revision with timestamp 
{$row->ar_timestamp} unavailable!\n" );
 
-                       return false; // bug 22624?
+                       return false; // T24624?
                }
                $text = $rev->getSerializedData();
                if ( !is_string( $text ) ) {
-                       # This should not happen, but sometimes does (bug 20757)
+                       # This should not happen, but sometimes does (T22757)
                        $this->output( "Data of revision with timestamp 
{$row->ar_timestamp} unavailable!\n" );
 
                        return false;
diff --git a/maintenance/rebuildFileCache.php b/maintenance/rebuildFileCache.php
index d073282..3520279 100644
--- a/maintenance/rebuildFileCache.php
+++ b/maintenance/rebuildFileCache.php
@@ -140,7 +140,7 @@
 
                                        MediaWiki\suppressWarnings(); // header 
notices
                                        // Cache ?action=view
-                                       $wgRequestTime = microtime( true ); # 
bug 22852
+                                       $wgRequestTime = microtime( true ); # 
T24852
                                        ob_start();
                                        $article->view();
                                        $context->getOutput()->output();
@@ -148,7 +148,7 @@
                                        $viewHtml = ob_get_clean();
                                        $viewCache->saveToFileCache( $viewHtml 
);
                                        // Cache ?action=history
-                                       $wgRequestTime = microtime( true ); # 
bug 22852
+                                       $wgRequestTime = microtime( true ); # 
T24852
                                        ob_start();
                                        Action::factory( 'history', $article, 
$context )->show();
                                        $context->getOutput()->output();
diff --git a/maintenance/sql.php b/maintenance/sql.php
index cc976ed..e42a8ef 100644
--- a/maintenance/sql.php
+++ b/maintenance/sql.php
@@ -137,7 +137,7 @@
                        }
                        if ( $historyFile ) {
                                # Delimiter is eated by streamStatementEnd, we 
add it
-                               # up in the history (bug 37020)
+                               # up in the history (T39020)
                                readline_add_history( $wholeLine . ';' );
                                readline_write_history( $historyFile );
                        }
diff --git a/maintenance/sqlite/archives/initial-indexes.sql 
b/maintenance/sqlite/archives/initial-indexes.sql
index f322a03..2d0c9ee 100644
--- a/maintenance/sqlite/archives/initial-indexes.sql
+++ b/maintenance/sqlite/archives/initial-indexes.sql
@@ -3,7 +3,7 @@
 -- Unique indexes need to be handled with INSERT SELECT since just running
 -- the CREATE INDEX statement will fail if there are duplicate values.
 --
--- Ignore duplicates, several tables will have them (e.g. bug 16966) but in
+-- Ignore duplicates, several tables will have them (e.g. T18966) but in
 -- most cases it's harmless to discard them.
 
 
--------------------------------------------------------------------------------
diff --git a/maintenance/storage/trackBlobs.php 
b/maintenance/storage/trackBlobs.php
index a2dc376..4f22843 100644
--- a/maintenance/storage/trackBlobs.php
+++ b/maintenance/storage/trackBlobs.php
@@ -69,7 +69,7 @@
                echo "Doing integrity check...\n";
                $dbr = wfGetDB( DB_REPLICA );
 
-               // Scan for HistoryBlobStub objects in the text table (bug 
20757)
+               // Scan for HistoryBlobStub objects in the text table (T22757)
 
                $exists = $dbr->selectField( 'text', 1,
                        'old_flags LIKE \'%object%\' AND old_flags NOT LIKE 
\'%external%\' ' .
@@ -84,7 +84,7 @@
                        exit( 1 );
                }
 
-               // Scan the archive table for HistoryBlobStub objects or 
external flags (bug 22624)
+               // Scan the archive table for HistoryBlobStub objects or 
external flags (T24624)
                $flags = $dbr->selectField( 'archive', 'ar_flags',
                        'ar_flags LIKE \'%external%\' OR (' .
                        'ar_flags LIKE \'%object%\' ' .
diff --git a/maintenance/tables.sql b/maintenance/tables.sql
index 892f799..44922a4 100644
--- a/maintenance/tables.sql
+++ b/maintenance/tables.sql
@@ -594,7 +594,7 @@
   -- conversion algorithm is run.  We store this so that we can update
   -- collations without reparsing all pages.
   -- Note: If you change the length of this field, you also need to change
-  -- code in LinksUpdate.php. See bug 25254.
+  -- code in LinksUpdate.php. See T27254.
   cl_sortkey_prefix varchar(255) binary NOT NULL default '',
 
   -- This isn't really used at present. Provided for an optional
@@ -816,7 +816,7 @@
   -- Size chosen to allow IPv6
   -- FIXME: these fields were originally blank for single-IP blocks,
   -- but now they are populated. No migration was ever done. They
-  -- should be fixed to be blank again for such blocks (bug 49504).
+  -- should be fixed to be blank again for such blocks (T51504).
   ipb_range_start tinyblob NOT NULL,
   ipb_range_end tinyblob NOT NULL,
 
diff --git a/maintenance/update.php b/maintenance/update.php
index a672e29..d96cecd 100755
--- a/maintenance/update.php
+++ b/maintenance/update.php
@@ -112,7 +112,7 @@
                }
 
                $lang = Language::factory( 'en' );
-               // Set global language to ensure localised errors are in 
English (bug 20633)
+               // Set global language to ensure localised errors are in 
English (T22633)
                RequestContext::getMain()->setLanguage( $lang );
                $wgLang = $lang; // BackCompat
 
@@ -203,7 +203,7 @@
 
                # Don't try to access the database
                # This needs to be disabled early since extensions will try to 
use the l10n
-               # cache from $wgExtensionFunctions (bug 20471)
+               # cache from $wgExtensionFunctions (T22471)
                $wgLocalisationCacheConf = [
                        'class' => 'LocalisationCache',
                        'storeClass' => 'LCStoreNull',

diff --git a/maintenance/storage/fixBug20757.php 
b/maintenance/storage/fixT22757.php
similarity index 97%
rename from maintenance/storage/fixBug20757.php
rename to maintenance/storage/fixT22757.php
index b444f31..e8bd23d 100644
--- a/maintenance/storage/fixBug20757.php
+++ b/maintenance/storage/fixT22757.php
@@ -1,6 +1,6 @@
 <?php
 /**
  * Script to fix bug 20757.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@
 require_once __DIR__ . '/../Maintenance.php';
 
 /**
  * Maintenance script to fix bug 20757.
  *
  * @ingroup Maintenance ExternalStorage
  */
-class FixBug20757 extends Maintenance {
+class FixT22757 extends Maintenance {
        public $batchSize = 10000;
        public $mapCache = [];
        public $mapCacheSize = 0;
@@ -36,7 +36,7 @@
 
        function __construct() {
                parent::__construct();
-               $this->addDescription( 'Script to fix bug 20757 assuming that 
blob_tracking is intact' );
+               $this->addDescription( 'Script to fix T22757 assuming that 
blob_tracking is intact' );
                $this->addOption( 'dry-run', 'Report only' );
                $this->addOption( 'start', 'old_id to start at', false, true );
        }
@@ -345,5 +345,5 @@
        }
 }
 
-$maintClass = 'FixBug20757';
+$maintClass = 'FixT22757';
 require_once RUN_MAINTENANCE_IF_MAIN;
@@ -1,6 +1,6 @@
 <?php
 /**
- * Script to fix bug 20757.
+ * Script to fix T22757.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,11 +24,11 @@
 
 /**
- * Maintenance script to fix bug 20757.
+ * Maintenance script to fix T22757.
  *
  * @ingroup Maintenance ExternalStorage
-- 
To view, visit https://gerrit.wikimedia.org/r/338907
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: If81a590d658fbd82c20c54ac47dfdc8856745ca3
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Jforrester <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to